package com.ruoyi.sim.mapper;

import java.util.List;

import com.ruoyi.sim.domain.Major;

/**
 * 专业Mapper接口
 *
 * @author tom
 * @date 2024-12-11
 */
public interface MajorMapper {
    /**
     * 查询专业
     *
     * @param majorId 专业主键
     * @return 专业
     */
    public Major selectMajorByMajorId(Long majorId);

    /**
     * 查询专业列表
     *
     * @param major 专业
     * @return 专业集合
     */
    public List<Major> selectMajorList(Major major);

    /**
     * 新增专业
     *
     * @param major 专业
     * @return 结果
     */
    public int insertMajor(Major major);

    /**
     * 修改专业
     *
     * @param major 专业
     * @return 结果
     */
    public int updateMajor(Major major);

    /**
     * 删除专业
     *
     * @param majorId 专业主键
     * @return 结果
     */
    public int deleteMajorByMajorId(Long majorId);

    /**
     * 批量删除专业
     *
     * @param majorIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMajorByMajorIds(Long[] majorIds);
}
